@@ -1,4 +1,4 @@
-eHOF.modelnames <- c("I", "II", "III", "IV", "V", "VI", "VII")
+eHOF.modelnames <- factor(c("I", "II", "III", "IV", "V", "VI", "VII"), ordered = TRUE)
 
 HOF.fun <- function (x, model, p, M = 1, ...) {
     model <- match.arg(model, eHOF.modelnames)
@@ -6,7 +6,7 @@ HOF.fun <- function (x, model, p, M = 1, ...) {
     #v <- list(M = M, a = p[1], b = p[2], c = p[3], d = p[4], e = p[5])
     x <- scale01(x, ...)
     if (length(M) == 1)  M <- rep(M, length(x))
-    fv <- switch(model, 
+    fv <- switch(as.character(model), 
            I = M/(1 + exp(a)),
           II = M/(1 + exp(a + b * x)),
          III = M/(1 + exp(a + b * x)) * 1/(1 + exp(c)),
@@ -18,8 +18,3 @@ HOF.fun <- function (x, model, p, M = 1, ...) {
     return(fv)
 }
 
-#HOF.modelformulas <- function(modelname, ...) {
-#fv <- switch(modelname, 
-#        I = "M/(1 + exp(a))",
-#  return(fv)
-#}
